% An example problem:
%
% Here we have 3 modalities (numMod = 3) with slopes (a's) = [.6 .7 .8],
% intercepts (b's) = [-.1 0 .1], and noise (sigma's) = [.05 .03 .08].
%
% Theta consists of 100 true ejection fractions (EFs) - they are beta 
% distributed with nu = 1.5 and omega = 2.  GenData modifies the true EFs
% with the linear model parameters (a's,b's,sigma's) to give us our data:
% ThetaHat.  
%
% Opt_normal maximizes the likelihood of the data given the model
% parameters and the parameters of the assumed distribution (in this case a
% truncated normal).  
%
% MakePlots generates plots using the data (ThetaHats) versus the
% true EFs (Theta's) and the estimated linear model parameters.  Note that
% the true EFs were not used to estimate the linear model parameters.  We
% are only able to generate these plots because we now the truth in
% simulation. 
%
% Here the data (beta distributed) did not match the model (truncated
% normal).  One is free to change this around by replacing betarnd with
% truncnorm and/or Opt_tnormal with Opt_beta.  
%

  Theta=betarnd(1.5,2,100,1);
  
  ThetaHat = GenData(Theta,[.6 .7 .8],[-.1 0 .1],[.05 .03 .08]);
  
  [aEst,bEst,sigEst,meanpEst,sigpEst] = Opt_tnormal(ThetaHat);

  MakePlots(Theta,ThetaHat,aEst,bEst,sigEst)  
  
  