function ThetaHat = GenData(Theta,a,b,sig)
%
%  Given the "Truth" (Theta), generate noisy measument data of the form
%  ThetaHat = a*Theta + b + noise(sig).  Where a, b, and sig are vectors
%  whose size determines the number of noisy measurements.
%
%  Example:  >> Theta = betarnd(1.5,2,100,1);  % Generate "Truth"
%            >> ThetaHat = GenData(Theta,[.5 .8],[0 0],[0.05 0.01]);
%
%  Note:  This generates Gaussian noise on the measurement data.
%

numMod = length(a);
numObs = length(Theta);

aFull   = a(ones(numObs,1),:);
bFull   = b(ones(numObs,1),:);
sigFull = sig(ones(numObs,1),:);

ThetaHat = aFull.*Theta(:,ones(numMod,1)) + bFull + ...
    randn(numObs,numMod).*sigFull;
