function  [aEst,bEst,sigEst,betaP] = Opt_beta(ThetaHat)
%
% function  [aEst,bEst,sigEst,betaP] = Opt_beta(ThetaHat,a,b,sig,dim)
%
% Run the "Estimation w/out a Gold Standard" routine using a varying Beta
% distrubtion as the assumed distribution.
%
% ThetaHat is generated using GenData.m
% Returns maximum-likelihood estimates of the linear model parameters
% {a,b,\sigma,\nu,\omega}

numMod = size(ThetaHat,2);
numObs = size(ThetaHat,1);

% Range of parameter searches

amin =  0.5;
amax =  1.2;
bmin = -0.5;
bmax =  0.5;
sigmin = 0.01;
sigmax = 0.3;

minvec = [ones(1,numMod)*amin ones(1,numMod)*bmin ...
      ones(1,numMod)*sigmin 1.1 1.1];
maxvec = [ones(1,numMod)*amax ones(1,numMod)*bmax ...
      ones(1,numMod)*sigmax 5 5];

% start in the middle 

startvec = ((maxvec - minvec) / 2) + minvec; 

% Call matlab optimization routine

warning off;
[vals,fval,exitflag] = fmincon('betacostfun',startvec,[],[],[],[],...
    minvec,maxvec,[],...
    optimset('TolX',1e-10,'Display','iter'),ThetaHat);
warning on;

if (exitflag <= 0),
  disp('Optimization may not have converged');
end

aEst = vals(1:numMod);
bEst = vals(numMod+1:2*numMod);
sigEst = vals(2*numMod+1:3*numMod);
betaP = vals(3*numMod+1:3*numMod+2);
