function  [aEst,bEst,sigEst,meanpEst,sigpEst] = Opt_tnormal(ThetaHat)
%
% function  [aEst,bEst,sigEst,meanpEst,sigpEst] = Opt_tnormal(ThetaHat)
%
% Run the "Estimation w/out a Gold Standard" routine using a varying 
% truncated-normal
% distrubtion as the assumed distribution.
%
% ThetaHat is generated using GenData.m
% Returns maximum-likelihood estimates of the linear model parameters
% {a,b,\sigma,\mu_a,\sigma_a}

numMod = size(ThetaHat,2);
numObs = size(ThetaHat,1);

% Range of parameter searches 

amin =  0.5;  
amax =  1.2;
bmin = -1;
bmax =  1;
sigmin = 0.01;
sigmax = 0.3;

minvec = [ones(1,numMod)*amin ones(1,numMod)*bmin ...
      ones(1,numMod)*sigmin 0 0.05 ];
maxvec = [ones(1,numMod)*amax ones(1,numMod)*bmax ...
      ones(1,numMod)*sigmax 1 3];
% start in the middle ?
startvec = ((maxvec - minvec) / 2) + minvec; 

% Call matlab optimization routine
warning off;
[vals,fval,exitflag] = fmincon('truncnormalcostfun',startvec,[],[],[],[],...
    minvec,maxvec,[],...
    optimset('TolX',1e-50,'Display','iter','MaxIter',1000,'MaxFunEvals',5000),ThetaHat);
warning on;

if (exitflag <= 0),
  disp('Optimization may not have converged');
end

aEst = vals(1:numMod);
bEst = vals(numMod+1:2*numMod);
sigEst = vals(2*numMod+1:3*numMod);
meanpEst = vals(3*numMod+1);
sigpEst = vals(3*numMod+2);
