function [val] = truncnormalcostfun(params,ThetaHat)
%
% Has a _varying_ normal assumed distribution.
%
% params = [a's b's sig's meanp sigp]
%

numObs = size(ThetaHat,1);
numMod = size(ThetaHat,2);

% Sometimes we take the log of zeros so turn warnings off
a          = params(1:numMod);
b          = params(numMod+1:2*numMod);
sig        = params(2*numMod+1:3*numMod);
meanp      = params(3*numMod+1);
sigp       = params(3*numMod+2);

aFull     = a(ones(numObs,1),:);
bFull     = b(ones(numObs,1),:);
sigFull   = sig(ones(numObs,1),:);
sigpFull  = sigp*ones(numObs,1);
meanpFull = meanp*ones(numObs,1);

%  The actual cost function evalutated in Opt_tnormal.m

A = 1./(2*sigpFull.^2) + sum((aFull.^2)./(2*sigFull.^2),2);
B = -meanpFull./(sigpFull.^2) + sum((aFull.*bFull-ThetaHat.*aFull)./(sigFull.^2),2);
C = (meanpFull.^2)./(2*sigpFull.^2) + sum(((ThetaHat - bFull).^2)./(2*sigFull.^2),2);

N = (sqrt(2))/(sigp*(erf((1-meanp)/(sqrt(2)*sigp))+erf(meanp/(sqrt(2)*sigp))));

P = log((1/(((2*pi)^(numMod/2))*prod(sig)))) + ...
    log((N/2)*sqrt(pi./A))+(B.^2-4*A.*C)./(4*A) + ...
    log(erf((2*A+B)./(2*A.^0.5)) - erf((B)./(2*A.^0.5)));

val = -sum(P);

if (val == Inf)
  disp('Inf Toubles');
end